# -*- coding: utf-8 -*-
##############################################################################
#
#    Remembership module for OpenERP, Overload membership module
#    Copyright (C) 2012 L'Heureux Cyclage (<http://www.heureux-cyclage.org>) Ludovic CHEVALIER
#
#    This file is a part of Remembership
#
#    Remembership is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Remembership is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv
from osv import fields


class Partner(osv.osv):
    _inherit = 'res.partner'

    _columns = {
        'member_ident': fields.char('Member identifier', size=64),
    }

    _sql_constraints = [
        ('member_ident_uniq', 'unique(member_ident, company_id)', 'The member identifier must be unique !'),
    ]

Partner()


class Product(osv.osv):
    _inherit = 'product.product'

    _columns = {
        'membership_grouped': fields.boolean('Grouped membership product', help='Check if it\'s a grouped membership product.'),
        'membership_date2date': fields.boolean('Date to date membership product', help='Check if it\'s a date to date membership product.'),
    }

Product()


class account_invoice_line(osv.osv):
    _inherit = 'account.invoice.line'

    def create(self, cr, uid, vals, context=None):
        res = super(account_invoice_line, self).create(cr, uid, vals, context=context)
        line = self.browse(cr, uid, res, context=context)

        if line.invoice_id.type == 'out_invoice' and line.product_id and line.product_id.membership:
            partners = [line.invoice_id.partner_id]
            partners.extend(line.invoice_id.partner_id.associate_members)
            for i in partners:
                if not i.member_ident:
                    mbr_id = self.pool.get('ir.sequence').get(cr, uid, 'member_ident')
                    self.pool.get('res.partner').write(cr, uid, i.id, {'member_ident': mbr_id})
        return res

account_invoice_line()


class pos_make_payment(osv.osv_memory):
    _inherit = 'pos.make.payment'

    def check(self, cr, uid, ids, context=None):
        """
        Auto invoice orders. Temporarly solution before make partner members just with orders, without invoice.
        """
        res = super(pos_make_payment, self).check(cr, uid, ids, context=context)

        order_obj = self.pool.get('pos.order')
        order_obj.action_invoice(cr, uid, ids, context=context)

        return res

pos_make_payment()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
